source@mandoc.bsd.lv
 help / color / mirror / Atom feed
* mandoc: Do not draw horizontal lines through vertical spans which are
@ 2018-11-29 23:08 schwarze
  0 siblings, 0 replies; only message in thread
From: schwarze @ 2018-11-29 23:08 UTC (permalink / raw)
  To: source

Log Message:
-----------
Do not draw horizontal lines through vertical spans
which are requested in the data section rather than in the layout.
Mini-feature found in misc/pfm(1).

Modified Files:
--------------
    mandoc:
        tbl_term.c

Revision Data
-------------
Index: tbl_term.c
===================================================================
RCS file: /home/cvs/mandoc/mandoc/tbl_term.c,v
retrieving revision 1.64
retrieving revision 1.65
diff -Ltbl_term.c -Ltbl_term.c -u -p -r1.64 -r1.65
--- tbl_term.c
+++ tbl_term.c
@@ -579,8 +579,9 @@ static void
 tbl_hrule(struct termp *tp, const struct tbl_span *spp,
     const struct tbl_span *spn, int flags)
 {
-	const struct tbl_cell	*cpp;    /* Cell above this line. */
-	const struct tbl_cell	*cpn;    /* Cell below this line. */
+	const struct tbl_cell	*cpp;    /* Layout cell above this line. */
+	const struct tbl_cell	*cpn;    /* Layout cell below this line. */
+	const struct tbl_dat	*dpn;	 /* Data cell below this line. */
 	const struct roffcol	*col;    /* Contains width and spacing. */
 	int			 opts;   /* For the table as a whole. */
 	int			 bw;	 /* Box line width. */
@@ -590,6 +591,13 @@ tbl_hrule(struct termp *tp, const struct
 
 	cpp = spp == NULL ? NULL : spp->layout->first;
 	cpn = spn == NULL ? NULL : spn->layout->first;
+	dpn = NULL;
+	if (spn != NULL) {
+		if (spn->pos == TBL_SPAN_DATA)
+			dpn = spn->first;
+		else if (spn->next != NULL)
+			dpn = spn->next->first;
+	}
 	opts = spn == NULL ? spp->opts->opts : spn->opts->opts;
 	bw = opts & TBL_OPT_DBOX ? (tp->enc == TERMENC_UTF8 ? 2 : 1) :
 	    opts & (TBL_OPT_BOX | TBL_OPT_ALLBOX) ? 1 : 0;
@@ -615,7 +623,9 @@ tbl_hrule(struct termp *tp, const struct
 		/* Print the horizontal line inside this column. */
 
 		lw = cpp == NULL || cpn == NULL ||
-		    cpn->pos != TBL_CELL_DOWN ? hw : 0;
+		    (cpn->pos != TBL_CELL_DOWN &&
+		     (dpn == NULL || strcmp(dpn->string, "\\^") != 0))
+		    ? hw : 0;
 		tbl_direct_border(tp, BHORIZ * lw,
 		    col->width + col->spacing / 2);
 
@@ -641,6 +651,8 @@ tbl_hrule(struct termp *tp, const struct
 					dw = 1;
 			}
 			cpn = cpn->next;
+			while (dpn != NULL && dpn->layout != cpn)
+				dpn = dpn->next;
 		}
 		if (cpp == NULL && cpn == NULL)
 			break;
@@ -655,7 +667,9 @@ tbl_hrule(struct termp *tp, const struct
 		/* The horizontal line inside the next column. */
 
 		rw = cpp == NULL || cpn == NULL ||
-		    cpn->pos != TBL_CELL_DOWN ? hw : 0;
+		    (cpn->pos != TBL_CELL_DOWN &&
+		     (dpn == NULL || strcmp(dpn->string, "\\^") != 0))
+		    ? hw : 0;
 
 		/* The line crossing at the end of this column. */
 
--
 To unsubscribe send an email to source+unsubscribe@mandoc.bsd.lv

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2018-11-29 23:08 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2018-11-29 23:08 mandoc: Do not draw horizontal lines through vertical spans which are schwarze

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).